@@ -21,6 +21,16 @@ require 'ruby_debian_dev'
 
 module Gem2Deb
 
+  class << self
+    attr_accessor :verbose
+    def testing
+      ENV['GEM2DEB_TESTING']
+    end
+    def testing=(v)
+      ENV['GEM2DEB_TESTING'] = v.to_s
+    end
+  end
+
   class CommandFailed < Exception
   end
 
@@ -40,13 +50,23 @@ module Gem2Deb
   LIBDIR = File.expand_path(File.dirname(__FILE__))
 
   def run(*argv)
-    puts(_format_cmdline(argv)) if $VERBOSE
+    puts(_format_cmdline(argv)) if Gem2Deb.verbose
     system(*argv)
     if $?.exitstatus != 0
       raise Gem2Deb::CommandFailed, _format_cmdline(argv)
     end
   end
 
+  def run_ruby(ruby, *args)
+    cmd = args.dup
+    if LIBDIR != '/usr/lib/ruby/vendor_ruby'
+      # only add LIBDIR to load path is not running the installed copy
+      cmd.unshift("-I", LIBDIR)
+    end
+    cmd.unshift(ruby)
+    run(*cmd)
+  end
+
   private
 
   def _format_cmdline(argv)
@@ -54,4 +74,6 @@ module Gem2Deb
   end
 end
 
+Gem2Deb.verbose = true
+
 require 'gem2deb/version'
