@@ -14,7 +14,9 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require 'gem2deb'
+require 'gem2deb/banner'
 require 'gem2deb/installer'
+require 'gem2deb/make'
 require 'find'
 require 'fileutils'
 
@@ -34,28 +36,27 @@ module Gem2Deb
     end
 
     def clean
-      puts "  Entering dh_ruby --clean" if @verbose
+      puts "   dh_ruby --clean" if @verbose
+
+      make.clean
 
       installers.each do |installer|
         installer.run_make_clean_on_extensions
       end
-
-      puts "  Leaving dh_ruby --clean" if @verbose
     end
 
     def configure
-      # puts "  Entering dh_ruby --configure" if @verbose
-      # puts "  Leaving dh_ruby --configure" if @verbose
+      # puts "   dh_ruby --configure" if @verbose
     end
 
     def build
-      # puts "  Entering dh_ruby --build" if @verbose
-      # puts "  Leaving dh_ruby --build" if @verbose
+      puts "   dh_ruby --build" if @verbose
+
+      make.build
     end
 
     def test
-      # puts "  Entering dh_ruby --test" if @verbose
-      # puts "  Leaving dh_ruby --test" if @verbose
+      # puts "   dh_ruby --test" if @verbose
     end
 
     if File.exist? File.expand_path(File.join(File.dirname(__FILE__),'../../bin','gem2deb-test-runner'))
@@ -65,7 +66,11 @@ module Gem2Deb
     end
 
     def install(argv)
-      puts "  Entering dh_ruby --install" if @verbose
+      puts "   dh_ruby --install" if @verbose
+
+      dh_auto_install_destdir = argv.first
+
+      make.install(destdir_for(packages.first[:binary_package], dh_auto_install_destdir))
 
       ruby_versions.each do |version|
         if !SUPPORTED_RUBY_VERSIONS.include?(version)
@@ -75,35 +80,27 @@ module Gem2Deb
       end
 
       installers.each do |installer|
-        installer.dh_auto_install_destdir = argv.first
+        installer.destdir_base = destdir_for(installer.binary_package, dh_auto_install_destdir)
         installer.install_files_and_build_extensions
         installer.update_shebangs
       end
 
-      run_tests
-
       installers.each do |installer|
         installer.install_substvars
         installer.install_gemspec
-        check_rubygems(installer)
       end
 
-      puts "  Leaving dh_ruby --install" if @verbose
+      run_tests
+
+      # FIXME remove this message after stretch
+      if File.exists?('debian/require-rubygems.overrides')
+        puts "W: debian/require-rubygems.overrides is obsolete, and is now ignored"
+      end
+
+      Gem2Deb::Banner.print 'dh_ruby --install finished'
     end
 
-    protected
-
-    def check_rubygems(installer)
-      if skip_checks?
-        return
-      end
-
-      begin
-        installer.check_rubygems
-      rescue Gem2Deb::Installer::RequireRubygemsFound
-        handle_test_failure("require-rubygems")
-      end
-    end
+    protected # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
     def handle_test_failure(test)
       if ENV['DH_RUBY_IGNORE_TESTS']
@@ -115,7 +112,7 @@ module Gem2Deb
           return
         end
       end
-      if STDIN.isatty and STDOUT.isatty and STDERR.isatty
+      if interactive
         # running interactively
         continue = nil
         begin
@@ -135,6 +132,12 @@ module Gem2Deb
       end
     end
 
+    def interactive
+      STDIN.isatty && STDOUT.isatty && STDERR.isatty &&
+        ENV['DEB_BUILD_OPTIONS'] &&
+        ENV['DEB_BUILD_OPTIONS'].split.include?('dh_ruby_interactive')
+    end
+
     def run_tests
       ruby_versions.each do |rubyver|
         run_tests_for_version(rubyver)
@@ -147,7 +150,7 @@ module Gem2Deb
       end
 
       begin
-        run(SUPPORTED_RUBY_VERSIONS[rubyver], '-I' + LIBDIR, TEST_RUNNER)
+        run_ruby(SUPPORTED_RUBY_VERSIONS[rubyver], TEST_RUNNER)
       rescue Gem2Deb::CommandFailed
         handle_test_failure(rubyver)
       end
@@ -226,5 +229,17 @@ module Gem2Deb
         end
     end
 
+    def make
+      @make ||= Gem2Deb::Make.new
+    end
+
+    def destdir_for(binary_package, dh_auto_install_destdir)
+      if ENV['DH_RUBY_USE_DH_AUTO_INSTALL_DESTDIR']
+        dh_auto_install_destdir
+      else
+        File.join('debian', binary_package.to_s)
+      end
+    end
+
   end
 end
