@@ -3,8 +3,8 @@ require 'rake/testtask'
 module Gem2Deb
   module Rake
     class TestTask < ::Rake::TestTask
-      def initialize
-        super(:default)
+      def initialize(name=:default)
+        super(name)
       end
       def define
         self.libs.reject! { |path| ['lib','ext'].include?(path) }
